# encoding: utf-8

module MyEpisodes
  class Client
    def self.create(username, password, agent=Mechanize.new)
      client = self.new(agent)
      client.login(username, password)
      client
    end

    def initialize(agent=Mechanize.new)
      @agent = agent
      @page = nil
    end

    def login(username, password)
      unless @page
        page = @agent.get(login_url)
        form = page.form_with(action: 'login.php', method: 'POST')
        form.username = username
        form.password = password
        form.u = life_wasted
        @page = form.submit(form.buttons.first)
        ensure_logged_in
      end
    end

    def shows
      @shows ||= Shows.new(parser).create(shows_links).to_a
    end

    def logout
      if @page
        @page.link_with(text: /Logout/).click
        @page = nil
      end
    end

    private

    def parser
      @parser ||= TableParser.new
    end

    def shows_links
      @shows_links ||= @page.links_with(href: /views\.php\?type=epsbyshow/)
    end

    def login_url
      @login_url ||= 'http://www.myepisodes.com/login.php'
    end

    def life_wasted
      @life_wasted ||= 'life_wasted.php'
    end

    def still_on_login_page?
      @page.title && @page.title.match(/: Login Page/i)
    end

    def login_warning?
      warning_text = @page.search('#divContainer div.warning').text.strip
      warning_text && warning_text.match(/wrong username.+password/i)
    end

    def ensure_logged_in
      if still_on_login_page? && login_warning?
        @page = nil
        raise AuthenticationError, 'wrong username / password'
      end
    end
  end
end
