# encoding: utf-8

module MyEpisodes
  class Episode
    attr_reader :air_date, :show_name, :number, :name

    def initialize(season)
      @season = season
    end

    def create(attrs)
      attrs = sanitize(attrs)
      @air_date = text(attrs[AIR_DATE_FIELD])
      @show_name = text(attrs[SHOW_NAME_FIELD])
      @number = text(attrs[NUMBER_FIELD])
      @name = text(attrs[NAME_FIELD])
      @acquired = checked?(attrs[ACQUIRED_FIELD])
      @watched = checked?(attrs[WATCHED_FIELD])
      self
    end

    def season
      @season.freeze
    end

    def acquired?
      !!@acquired
    end

    def watched?
      !!@watched
    end

    private

    def sanitize(attrs)
      attrs.reject.with_index { |a, i| i.even? }
    end

    def text(a)
      a.text.strip
    end

    def checked?(a)
      a.children.any? && a.children.last.attr(CHECKED) == CHECKED
    end

    CHECKED = 'checked'.freeze
    AIR_DATE_FIELD = 0
    SHOW_NAME_FIELD = 1
    NUMBER_FIELD = 2
    NAME_FIELD = 3
    ACQUIRED_FIELD = 4
    WATCHED_FIELD = 5
  end
end
